import { Button, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { columns, defaultConfig } from "./user_config";
import "./user.less";

const User = (props: Store) => {
  const { usrStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [team, setTeam] = useState<any>(null);
  const [per, setPer] = useState<any>(null);
  const [userId, setId] = useState<Number | null>(null);
  const actionWidget = (any, record) => {
    return (
      <Space wrap>
        <Button
          type="dashed"
          size="small"
          onClick={() => {
            edit(record);
          }}
        >
          编辑
        </Button>

        <Button
          type="dashed"
          danger
          size="small"
          onClick={() => {
            usrStore.deleteItem(record.id);
          }}
        >
          删除
        </Button>
      </Space>
    );
  };

  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig(team,per));
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    let data = {
      ...values,
    };
    if(values.head_img && values.head_img.length>0){
      data.head_img = values.head_img[0].url;
    }else{
      data.head_img = "";
    }
    if (!userId) {
      usrStore.add(data);
    } else {
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    usrStore.getlist();
    usrStore.getTeam().then((res) => {
      let data =res.data?.record??[]
      for (let index = 0; index < data.length; index++) {
         data[index].label = data[index].name;
         data[index].value = data[index].identity;
      }
      console.log(data);
      
      setTeam(data)
    });
    usrStore.getPer().then((res) => {
      let data =res.data?.record??[]
      for (let index = 0; index < data.length; index++) {
         data[index].label = data[index].name;
         data[index].value = data[index].identity;
      }
      setPer(data)
    });
    
  }, [usrStore]);

  const addHandler = () => {
    setProjectConfig(defaultConfig(team,per));
    setId(null);
    setIsModalOpen(true);
  };
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button type="default" onClick={() => addHandler()}>
            添加民兵
          </Button>
        </Space>
        <BTable
          store={usrStore}
          columns={[
            ...columns,
            {
              title: "操作",
              dataIndex: "id",
              fixed: "right",
              ellipsis: { showTitle: false },
              render: (any, record) => actionWidget(any, record),
            },
          ]}
          dataSource={usrStore.list}
        />
        <Modal
          title={!userId ? "添加民兵" : "编辑民兵"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          okText="确定"
          cancelText="取消"
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={25}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("usrStore")(observer(User));
